function yN = taylorreihenmethode(y0, T, N)

    % time step
    h = T/N;

    % time series
    t = zeros(N+1);
    for n=1:N+1
        t(n) = (n-1)*h;
    end

    % initial solution
    y = zeros(N+1);
    y(1) = y0;

    % solve from 0 -> T
    for n=1:N
        coeffs = getTaylorCoeffs(t(n), y(n));
        y(n+1) = y(n) + coeffs(1)*h + coeffs(2)*h^2 + coeffs(3)*h^3 + coeffs(4)*h^4;
    end
    
    yN = y(N+1);
end

% evaluate coefficients
function coeffs = getTaylorCoeffs(t, y)

    coeffs = zeros(4,1);
    coeffs(1) = -2*t*y^2;
    coeffs(2) = -y^2 - 2*coeffs(1)*t*y;
    coeffs(3) = +(1/3)*(-4*coeffs(1)*y - 2*t*(coeffs(1)^2 + 2*coeffs(2)*y));
    coeffs(4) = -(0.5*coeffs(1)^2 + coeffs(2)*y + t*(coeffs(1)*coeffs(2) + coeffs(3)*y));

end